# -*- coding: utf-8 -*-


from django.conf import settings
from django.contrib import admin
from django.utils.translation import ugettext as _

from thux.bank.admin import BankInline
from thux.organization import models


class ContactInline(admin.StackedInline):
    model = models.Contact
    extra = 0
    exclude = ['date_create', 'date_last_modify', 'creator', 'last_modifier', ]
    fieldsets = (
        (_('general information'), {
            'fields': (
                'default',
                'status',
                'code',
                'user',
                ('role', 'title',),
                ('last_name', 'first_name'),
                ('phone', 'fax',),
                ('mobile', 'email'),
                'photo',
                'note',
                'ordering',
                'contact_groups'
            )
        }),
    )


class ContactEmailInline(admin.TabularInline):
    model = models.ContactEmail
    extra = 0
    exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier',)
    fieldsets = (
        (_('general information'), {
            'fields': ('typology', 'email',)
        }),
    )


class ContactPhoneInline(admin.TabularInline):
    model = models.ContactPhone
    extra = 0
    exclude = ['date_create', 'date_last_modify', 'creator', 'last_modifier', ]
    fieldsets = (
        (_('general information'), {
            'fields': ('typology', 'phone',)
        }),
    )


class OrganizationAddressInline(admin.StackedInline):
    model = models.OrganizationAddress
    extra = 0
    fieldsets = (
        (_('general information'), {
            'fields': (
                'status', 'address_scopes', ('address_type', 'name'),
                ('number', 'zip_code'), ('locality', 'province'),
                'country', 'note'
            )
        }),
    )
    exclude = ['date_create', 'date_last_modify', 'creator', 'last_modifier']


class OrganizationEmailInline(admin.TabularInline):
    model = models.OrganizationEmail
    extra = 0
    exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier',)
    fieldsets = (
        (_('general information'), {
            'fields': ('typology', 'email',)
        }),
    )


class OrganizationSocialPageInline(admin.TabularInline):
    model = models.OrganizationSocialPage
    extra = 0
    exclude = ('date_create', 'date_last_modify', 'creator', 'last_modifier',)
    fieldsets = (
        (_('general information'), {
            'fields': ('social', 'link',)
        }),
    )


class OrganizationAdmin(admin.ModelAdmin):
    fieldsets = (
        (_('general information'), {
            'fields': (
                ('code', 'name',),
                'organization_type', 'organization_form',
                'vat', 'delivery',
                'payment_form', 'currency',
                'vat_number', 'ssn',
                ('url', 'email'),
                ('phone', 'phone2',),
                'fax',
                'organization_groups',
            )
        }),
        (_('visualization admin'), {
            'fields': ('ordering', 'status',),
        }),
        (_('note'), {
            'fields': ('note',),
        }),
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    inlines = (
        ContactInline, OrganizationAddressInline,
        OrganizationEmailInline, OrganizationSocialPageInline
    )
    # inlines = [ContactInline, OrganizationAddressInline, BankInline] TODO
    list_display = (
        'get_status_display', 'code', 'get_organization_type', 'name', 'phone',
        'phone2', 'fax', 'get_icon_link_url', 'get_icon_link_email',
    )
    search_fields = ('code', 'name',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify',)

    def get_link_url(self, obj):
        """
        Return link to organization URL
        """
        if obj.url:
            return '<a href={url} target="_blank">{url}</a>'.format(
                url=obj.url,
            )
        return ""
    get_link_url.short_description = _("url")
    get_link_url.allow_tags = True

    def get_icon_link_url(self, obj):
        """
        Return link icon to organization URL
        """
        if obj.url:
            return """
                <a href={href} target="_blank">x</a>""".format(
                    href=obj.url,
                    url=settings.MEDIA_URL,
                    title=obj.url,
                )
        return ""
    get_icon_link_url.short_description = _("www")
    get_icon_link_url.allow_tags = True

    def get_link_email(self, obj):
        """
        Return link to organization email
        """
        if obj.email:
            return "<a href=mailto:{email}>{email}</a>".format(
                email=obj.email,
            )
        return ""
    get_link_email.short_description = _("email")
    get_link_email.allow_tags = True

    def get_icon_link_email(self, obj):
        """
        Return link icon to organization email
        """
        if obj.email:
            return """
                <a href=mailto:{email}>x</a>""".format(
                    email=obj.email,
                    url=settings.STATIC_URL,
                    title=obj.email,
                )
        return ""
    get_icon_link_email.short_description = _("email")
    get_icon_link_email.allow_tags = True

    def get_organization_type(self, result):
        """
        Return organization type name
        """
        return "<b>{organization_type}</b>".format(
            organization_type=result.organization_type.name,
        )
    get_organization_type.short_description = _("type")
    get_organization_type.order_admin_field = 'organization_type__category__name'
    get_organization_type.allow_tags = True


class OwnerOrganizationAdmin(OrganizationAdmin):
    pass


class CustomerOrganizationAdmin(OrganizationAdmin):
    pass


class SupplierOrganizationAdmin(OrganizationAdmin):
    pass


class VectorOrganizationAdmin(OrganizationAdmin):
    pass


class OrganizationGroupAdmin(admin.ModelAdmin):
    fieldsets = (
        (_('general information'), {
            'fields': ('code', 'name', 'description')
        }),
        (_('visualization admin'), {
            'fields': ('ordering', 'status',),
        }),
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    list_display = ('get_status_display', 'code', 'name', 'ordering')
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify',)


class OrganizationFormAdmin(admin.ModelAdmin):
    fieldsets = (
        (_('general information'), {
            'fields': ('code', 'name')
        }),
        (_('visualization admin'), {
            'fields': ('ordering', 'status',),
        }),
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    list_display = ('get_status_display', 'code', 'name', 'ordering',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify',)


class OrganizationTypeAdmin(admin.ModelAdmin):
    fieldsets = (
        (_('general information'), {
            'fields': ('category', 'code', 'name',),
        }),
        (_('visualization admin'), {
            'fields': ('ordering', 'status',),
        }),
        (_('note'), {
            'fields': ('description', 'note',),
        }),
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    list_display = ('get_status_display', 'code', 'name', 'category', 'ordering',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify',)


class FieldAdmin(admin.ModelAdmin):
    fieldsets = (
        (_('general information'), {
            'fields': ('code', 'name',)
        }),
        (_('visualization admin'), {
            'fields': ('ordering', 'status',),
        }),
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    list_display = (
        'get_status_display', 'code', 'name', 'ordering',
    )
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify',)


class ContactRoleAdmin(admin.ModelAdmin):
    fieldsets = (
        (_('general information'), {
            'fields': ('code', 'name',),
        }),
        (_('visualization admin'), {
            'fields': ('ordering', 'status',),
        }),
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    list_display = ('get_status_display', 'code', 'name', 'ordering',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify',)


class ContactTitleAdmin(admin.ModelAdmin):
    fieldsets = (
        (_('general information'), {
            'fields': ('code', 'name', 'abbreviation')
        }),
        (_('visualization admin'), {
            'fields': ('ordering', 'status',),
        }),
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    list_display = ('get_status_display', 'code', 'name', 'abbreviation',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify',)


class ContactAdmin(admin.ModelAdmin):
    fieldsets = (
        (_('general information'), {
            'fields': (
                'default',
                'in_addressbook',
                'code',
                'user',
                'language',
                'organization',
                'role',
                'title',
                ('last_name', 'first_name'),
                ('phone', 'fax',),
                ('mobile', 'email'),
                'photo',
                'contact_groups',
            )
        }),
        (_('visualization admin'), {
            'fields': ('ordering', 'status',),
        }),
        (_('note'), {
            'fields': ('note',),
        }),
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    list_display = (
        'get_status_display', 'code', 'last_name', 'first_name', 'role', 'organization',
        'phone', 'mobile', 'fax', 'get_icon_link_email',
    )
    list_filter = ('status', 'role', 'title')
    search_fields = ('last_name', 'first_name')
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify',)
    inlines = (ContactEmailInline, ContactPhoneInline,)

    def get_link_email(self, obj):
        """
        Return link to contact email
        """
        if obj.email:
            return "<a href=mailto:{email}>{email}</a>".format(
                email=obj.email,
            )
        return ""
    get_link_email.short_description = _("email")
    get_link_email.allow_tags = True

    def get_icon_link_email(self, obj):
        """
        Return icon link to contact email
        """
        if obj.email:
            return """
                <a href=mailto:{email}>x</a>
                """.format(
                    email=obj.email,
                    url=settings.STATIC_URL,
                    title=obj.email,
                )
        return ""
    get_icon_link_email.short_description = _("email")
    get_icon_link_email.allow_tags = True


class OwnerContactAdmin(ContactAdmin):
    pass


class CustomerContactAdmin(ContactAdmin):
    pass


class SupplierContactAdmin(ContactAdmin):
    pass


class WorkerContactAdmin(ContactAdmin):
    pass


class VectorContactAdmin(ContactAdmin):
    pass


class EmailTypologyAdmin(admin.ModelAdmin):
    fieldsets = (
        (_('general information'), {
            'fields': ('code', 'name', 'slug')
        }),
        (_('visualization admin'), {
            'fields': ('ordering', 'status',),
        }),
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    list_display = ('get_status_display', 'code', 'name', 'slug',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify',)
    prepopulated_fields = {'slug': ('name',)}


class PhoneTypologyAdmin(admin.ModelAdmin):
    fieldsets = (
        (_('general information'), {
            'fields': ('code', 'name', 'slug')
        }),
        (_('visualization admin'), {
            'fields': ('ordering', 'status',),
        }),
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
        }),
    )
    list_display = ('get_status_display', 'code', 'name', 'slug',)
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify',)
    prepopulated_fields = {'slug': ('name',)}


admin.site.register(models.Organization, OrganizationAdmin)
admin.site.register(models.OwnerOrganization, OwnerOrganizationAdmin)
admin.site.register(models.CustomerOrganization, CustomerOrganizationAdmin)
admin.site.register(models.SupplierOrganization, SupplierOrganizationAdmin)
admin.site.register(models.VectorOrganization, VectorOrganizationAdmin)
admin.site.register(models.OrganizationGroup, OrganizationGroupAdmin)
admin.site.register(models.OrganizationForm, OrganizationFormAdmin)
admin.site.register(models.OrganizationType, OrganizationTypeAdmin)
admin.site.register(models.Field, FieldAdmin)
admin.site.register(models.ContactRole, ContactRoleAdmin)
admin.site.register(models.ContactTitle, ContactTitleAdmin)
admin.site.register(models.Contact, ContactAdmin)
admin.site.register(models.OwnerContact, OwnerContactAdmin)
admin.site.register(models.CustomerContact, CustomerContactAdmin)
admin.site.register(models.SupplierContact, SupplierContactAdmin)
admin.site.register(models.WorkerContact, WorkerContactAdmin)
admin.site.register(models.VectorContact, VectorContactAdmin)
admin.site.register(models.EmailTypology, EmailTypologyAdmin)
admin.site.register(models.PhoneTypology, PhoneTypologyAdmin)
